#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hashable
version: 1.2.4.0
id: hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
key: hasha_EalUWgp8NarBYWPbvYAD8I
license: BSD3
maintainer: johan.tibell@gmail.com
stability: Provisional
homepage: http://github.com/tibbe/hashable
synopsis: A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.
category: Data
author: Milan Straka <fox@ucw.cz>
        Johan Tibell <johan.tibell@gmail.com>
exposed: True
exposed-modules:
    Data.Hashable
hidden-modules: Data.Hashable.Class Data.Hashable.Generic
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hashable-1.2.4.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/hashable-1.2.4.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/hashable-1.2.4.0
hs-libraries: HShashable-1.2.4.0-EalUWgp8NarBYWPbvYAD8I
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    integer-gmp-1.0.0.0-4ff98693d6e5d6065e60052264067c09
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html: /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
